// Created with Squiffy 5.1.3
// https://github.com/textadventures/squiffy

(function(){
/* jshint quotmark: single */
/* jshint evil: true */

var squiffy = {};

(function () {
    'use strict';

    squiffy.story = {};

    var initLinkHandler = function () {
        var handleLink = function (link) {
            if (link.hasClass('disabled')) return;
            var passage = link.data('passage');
            var section = link.data('section');
            var rotateAttr = link.attr('data-rotate');
            var sequenceAttr = link.attr('data-sequence');
            if (passage) {
                disableLink(link);
                squiffy.set('_turncount', squiffy.get('_turncount') + 1);
                passage = processLink(passage);
                if (passage) {
                    currentSection.append('<hr/>');
                    squiffy.story.passage(passage);
                }
                var turnPassage = '@' + squiffy.get('_turncount');
                if (turnPassage in squiffy.story.section.passages) {
                    squiffy.story.passage(turnPassage);
                }
                if ('@last' in squiffy.story.section.passages && squiffy.get('_turncount')>= squiffy.story.section.passageCount) {
                    squiffy.story.passage('@last');
                }
            }
            else if (section) {
                currentSection.append('<hr/>');
                disableLink(link);
                section = processLink(section);
                squiffy.story.go(section);
            }
            else if (rotateAttr || sequenceAttr) {
                var result = rotate(rotateAttr || sequenceAttr, rotateAttr ? link.text() : '');
                link.html(result[0].replace(/&quot;/g, '"').replace(/&#39;/g, '\''));
                var dataAttribute = rotateAttr ? 'data-rotate' : 'data-sequence';
                link.attr(dataAttribute, result[1]);
                if (!result[1]) {
                    disableLink(link);
                }
                if (link.attr('data-attribute')) {
                    squiffy.set(link.attr('data-attribute'), result[0]);
                }
                squiffy.story.save();
            }
        };

        squiffy.ui.output.on('click', 'a.squiffy-link', function () {
            handleLink(jQuery(this));
        });

        squiffy.ui.output.on('keypress', 'a.squiffy-link', function (e) {
            if (e.which !== 13) return;
            handleLink(jQuery(this));
        });

        squiffy.ui.output.on('mousedown', 'a.squiffy-link', function (event) {
            event.preventDefault();
        });
    };

    var disableLink = function (link) {
        link.addClass('disabled');
        link.attr('tabindex', -1);
    }
    
    squiffy.story.begin = function () {
        if (!squiffy.story.load()) {
            squiffy.story.go(squiffy.story.start);
        }
    };

    var processLink = function(link) {
		link = String(link);
        var sections = link.split(',');
        var first = true;
        var target = null;
        sections.forEach(function (section) {
            section = section.trim();
            if (startsWith(section, '@replace ')) {
                replaceLabel(section.substring(9));
            }
            else {
                if (first) {
                    target = section;
                }
                else {
                    setAttribute(section);
                }
            }
            first = false;
        });
        return target;
    };

    var setAttribute = function(expr) {
        var lhs, rhs, op, value;
        var setRegex = /^([\w]*)\s*=\s*(.*)$/;
        var setMatch = setRegex.exec(expr);
        if (setMatch) {
            lhs = setMatch[1];
            rhs = setMatch[2];
            if (isNaN(rhs)) {
				if(startsWith(rhs,"@")) rhs=squiffy.get(rhs.substring(1));
                squiffy.set(lhs, rhs);
            }
            else {
                squiffy.set(lhs, parseFloat(rhs));
            }
        }
        else {
			var incDecRegex = /^([\w]*)\s*([\+\-\*\/])=\s*(.*)$/;
            var incDecMatch = incDecRegex.exec(expr);
            if (incDecMatch) {
                lhs = incDecMatch[1];
                op = incDecMatch[2];
				rhs = incDecMatch[3];
				if(startsWith(rhs,"@")) rhs=squiffy.get(rhs.substring(1));
				rhs = parseFloat(rhs);
                value = squiffy.get(lhs);
                if (value === null) value = 0;
                if (op == '+') {
                    value += rhs;
                }
                if (op == '-') {
                    value -= rhs;
                }
				if (op == '*') {
					value *= rhs;
				}
				if (op == '/') {
					value /= rhs;
				}
                squiffy.set(lhs, value);
            }
            else {
                value = true;
                if (startsWith(expr, 'not ')) {
                    expr = expr.substring(4);
                    value = false;
                }
                squiffy.set(expr, value);
            }
        }
    };

    var replaceLabel = function(expr) {
        var regex = /^([\w]*)\s*=\s*(.*)$/;
        var match = regex.exec(expr);
        if (!match) return;
        var label = match[1];
        var text = match[2];
        if (text in squiffy.story.section.passages) {
            text = squiffy.story.section.passages[text].text;
        }
        else if (text in squiffy.story.sections) {
            text = squiffy.story.sections[text].text;
        }
        var stripParags = /^<p>(.*)<\/p>$/;
        var stripParagsMatch = stripParags.exec(text);
        if (stripParagsMatch) {
            text = stripParagsMatch[1];
        }
        var $labels = squiffy.ui.output.find('.squiffy-label-' + label);
        $labels.fadeOut(1000, function() {
            $labels.html(squiffy.ui.processText(text));
            $labels.fadeIn(1000, function() {
                squiffy.story.save();
            });
        });
    };

    squiffy.story.go = function(section) {
        squiffy.set('_transition', null);
        newSection();
        squiffy.story.section = squiffy.story.sections[section];
        if (!squiffy.story.section) return;
        squiffy.set('_section', section);
        setSeen(section);
        var master = squiffy.story.sections[''];
        if (master) {
            squiffy.story.run(master);
            squiffy.ui.write(master.text);
        }
        squiffy.story.run(squiffy.story.section);
        // The JS might have changed which section we're in
        if (squiffy.get('_section') == section) {
            squiffy.set('_turncount', 0);
            squiffy.ui.write(squiffy.story.section.text);
            squiffy.story.save();
        }
    };

    squiffy.story.run = function(section) {
        if (section.clear) {
            squiffy.ui.clearScreen();
        }
        if (section.attributes) {
            processAttributes(section.attributes);
        }
        if (section.js) {
            section.js();
        }
    };

    squiffy.story.passage = function(passageName) {
        var passage = squiffy.story.section.passages[passageName];
        if (!passage) return;
        setSeen(passageName);
        var masterSection = squiffy.story.sections[''];
        if (masterSection) {
            var masterPassage = masterSection.passages[''];
            if (masterPassage) {
                squiffy.story.run(masterPassage);
                squiffy.ui.write(masterPassage.text);
            }
        }
        var master = squiffy.story.section.passages[''];
        if (master) {
            squiffy.story.run(master);
            squiffy.ui.write(master.text);
        }
        squiffy.story.run(passage);
        squiffy.ui.write(passage.text);
        squiffy.story.save();
    };

    var processAttributes = function(attributes) {
        attributes.forEach(function (attribute) {
            if (startsWith(attribute, '@replace ')) {
                replaceLabel(attribute.substring(9));
            }
            else {
                setAttribute(attribute);
            }
        });
    };

    squiffy.story.restart = function() {
        if (squiffy.ui.settings.persist && window.localStorage) {
            var keys = Object.keys(localStorage);
            jQuery.each(keys, function (idx, key) {
                if (startsWith(key, squiffy.story.id)) {
                    localStorage.removeItem(key);
                }
            });
        }
        else {
            squiffy.storageFallback = {};
        }
        if (squiffy.ui.settings.scroll === 'element') {
            squiffy.ui.output.html('');
            squiffy.story.begin();
        }
        else {
            location.reload();
        }
    };

    squiffy.story.save = function() {
        squiffy.set('_output', squiffy.ui.output.html());
    };

    squiffy.story.load = function() {
        var output = squiffy.get('_output');
        if (!output) return false;
        squiffy.ui.output.html(output);
        currentSection = jQuery('#' + squiffy.get('_output-section'));
        squiffy.story.section = squiffy.story.sections[squiffy.get('_section')];
        var transition = squiffy.get('_transition');
        if (transition) {
            eval('(' + transition + ')()');
        }
        return true;
    };

    var setSeen = function(sectionName) {
        var seenSections = squiffy.get('_seen_sections');
        if (!seenSections) seenSections = [];
        if (seenSections.indexOf(sectionName) == -1) {
            seenSections.push(sectionName);
            squiffy.set('_seen_sections', seenSections);
        }
    };

    squiffy.story.seen = function(sectionName) {
        var seenSections = squiffy.get('_seen_sections');
        if (!seenSections) return false;
        return (seenSections.indexOf(sectionName) > -1);
    };
    
    squiffy.ui = {};

    var currentSection = null;
    var screenIsClear = true;
    var scrollPosition = 0;

    var newSection = function() {
        if (currentSection) {
            disableLink(jQuery('.squiffy-link', currentSection));
        }
        var sectionCount = squiffy.get('_section-count') + 1;
        squiffy.set('_section-count', sectionCount);
        var id = 'squiffy-section-' + sectionCount;
        currentSection = jQuery('<div/>', {
            id: id,
        }).appendTo(squiffy.ui.output);
        squiffy.set('_output-section', id);
    };

    squiffy.ui.write = function(text) {
        screenIsClear = false;
        scrollPosition = squiffy.ui.output.height();
        currentSection.append(jQuery('<div/>').html(squiffy.ui.processText(text)));
        squiffy.ui.scrollToEnd();
    };

    squiffy.ui.clearScreen = function() {
        squiffy.ui.output.html('');
        screenIsClear = true;
        newSection();
    };

    squiffy.ui.scrollToEnd = function() {
        var scrollTo, currentScrollTop, distance, duration;
        if (squiffy.ui.settings.scroll === 'element') {
            scrollTo = squiffy.ui.output[0].scrollHeight - squiffy.ui.output.height();
            currentScrollTop = squiffy.ui.output.scrollTop();
            if (scrollTo > currentScrollTop) {
                distance = scrollTo - currentScrollTop;
                duration = distance / 0.4;
                squiffy.ui.output.stop().animate({ scrollTop: scrollTo }, duration);
            }
        }
        else {
            scrollTo = scrollPosition;
            currentScrollTop = Math.max(jQuery('body').scrollTop(), jQuery('html').scrollTop());
            if (scrollTo > currentScrollTop) {
                var maxScrollTop = jQuery(document).height() - jQuery(window).height();
                if (scrollTo > maxScrollTop) scrollTo = maxScrollTop;
                distance = scrollTo - currentScrollTop;
                duration = distance / 0.5;
                jQuery('body,html').stop().animate({ scrollTop: scrollTo }, duration);
            }
        }
    };

    squiffy.ui.processText = function(text) {
        function process(text, data) {
            var containsUnprocessedSection = false;
            var open = text.indexOf('{');
            var close;
            
            if (open > -1) {
                var nestCount = 1;
                var searchStart = open + 1;
                var finished = false;
             
                while (!finished) {
                    var nextOpen = text.indexOf('{', searchStart);
                    var nextClose = text.indexOf('}', searchStart);
         
                    if (nextClose > -1) {
                        if (nextOpen > -1 && nextOpen < nextClose) {
                            nestCount++;
                            searchStart = nextOpen + 1;
                        }
                        else {
                            nestCount--;
                            searchStart = nextClose + 1;
                            if (nestCount === 0) {
                                close = nextClose;
                                containsUnprocessedSection = true;
                                finished = true;
                            }
                        }
                    }
                    else {
                        finished = true;
                    }
                }
            }
            
            if (containsUnprocessedSection) {
                var section = text.substring(open + 1, close);
                var value = processTextCommand(section, data);
                text = text.substring(0, open) + value + process(text.substring(close + 1), data);
            }
            
            return (text);
        }

        function processTextCommand(text, data) {
            if (startsWith(text, 'if ')) {
                return processTextCommand_If(text, data);
            }
            else if (startsWith(text, 'else:')) {
                return processTextCommand_Else(text, data);
            }
            else if (startsWith(text, 'label:')) {
                return processTextCommand_Label(text, data);
            }
            else if (/^rotate[: ]/.test(text)) {
                return processTextCommand_Rotate('rotate', text, data);
            }
            else if (/^sequence[: ]/.test(text)) {
                return processTextCommand_Rotate('sequence', text, data);   
            }
            else if (text in squiffy.story.section.passages) {
                return process(squiffy.story.section.passages[text].text, data);
            }
            else if (text in squiffy.story.sections) {
                return process(squiffy.story.sections[text].text, data);
            }
			else if (startsWith(text,'@') && !startsWith(text,'@replace')) {
				processAttributes(text.substring(1).split(","));
				return "";
			}
            return squiffy.get(text);
        }

        function processTextCommand_If(section, data) {
            var command = section.substring(3);
            var colon = command.indexOf(':');
            if (colon == -1) {
                return ('{if ' + command + '}');
            }

            var text = command.substring(colon + 1);
            var condition = command.substring(0, colon);
			condition = condition.replace("<", "&lt;");
            var operatorRegex = /([\w ]*)(=|&lt;=|&gt;=|&lt;&gt;|&lt;|&gt;)(.*)/;
            var match = operatorRegex.exec(condition);

            var result = false;

            if (match) {
                var lhs = squiffy.get(match[1]);
                var op = match[2];
                var rhs = match[3];

				if(startsWith(rhs,'@')) rhs=squiffy.get(rhs.substring(1));
				
                if (op == '=' && lhs == rhs) result = true;
                if (op == '&lt;&gt;' && lhs != rhs) result = true;
                if (op == '&gt;' && lhs > rhs) result = true;
                if (op == '&lt;' && lhs < rhs) result = true;
                if (op == '&gt;=' && lhs >= rhs) result = true;
                if (op == '&lt;=' && lhs <= rhs) result = true;
            }
            else {
                var checkValue = true;
                if (startsWith(condition, 'not ')) {
                    condition = condition.substring(4);
                    checkValue = false;
                }

                if (startsWith(condition, 'seen ')) {
                    result = (squiffy.story.seen(condition.substring(5)) == checkValue);
                }
                else {
                    var value = squiffy.get(condition);
                    if (value === null) value = false;
                    result = (value == checkValue);
                }
            }

            var textResult = result ? process(text, data) : '';

            data.lastIf = result;
            return textResult;
        }

        function processTextCommand_Else(section, data) {
            if (!('lastIf' in data) || data.lastIf) return '';
            var text = section.substring(5);
            return process(text, data);
        }

        function processTextCommand_Label(section, data) {
            var command = section.substring(6);
            var eq = command.indexOf('=');
            if (eq == -1) {
                return ('{label:' + command + '}');
            }

            var text = command.substring(eq + 1);
            var label = command.substring(0, eq);

            return '<span class="squiffy-label-' + label + '">' + process(text, data) + '</span>';
        }

        function processTextCommand_Rotate(type, section, data) {
            var options;
            var attribute = '';
            if (section.substring(type.length, type.length + 1) == ' ') {
                var colon = section.indexOf(':');
                if (colon == -1) {
                    return '{' + section + '}';
                }
                options = section.substring(colon + 1);
                attribute = section.substring(type.length + 1, colon);
            }
            else {
                options = section.substring(type.length + 1);
            }
            var rotation = rotate(options.replace(/"/g, '&quot;').replace(/'/g, '&#39;'));
            if (attribute) {
                squiffy.set(attribute, rotation[0]);
            }
            return '<a class="squiffy-link" data-' + type + '="' + rotation[1] + '" data-attribute="' + attribute + '" role="link">' + rotation[0] + '</a>';
        }

        var data = {
            fulltext: text
        };
        return process(text, data);
    };

    squiffy.ui.transition = function(f) {
        squiffy.set('_transition', f.toString());
        f();
    };

    squiffy.storageFallback = {};

    squiffy.set = function(attribute, value) {
        if (typeof value === 'undefined') value = true;
        if (squiffy.ui.settings.persist && window.localStorage) {
            localStorage[squiffy.story.id + '-' + attribute] = JSON.stringify(value);
        }
        else {
            squiffy.storageFallback[attribute] = JSON.stringify(value);
        }
        squiffy.ui.settings.onSet(attribute, value);
    };

    squiffy.get = function(attribute) {
        var result;
        if (squiffy.ui.settings.persist && window.localStorage) {
            result = localStorage[squiffy.story.id + '-' + attribute];
        }
        else {
            result = squiffy.storageFallback[attribute];
        }
        if (!result) return null;
        return JSON.parse(result);
    };

    var startsWith = function(string, prefix) {
        return string.substring(0, prefix.length) === prefix;
    };

    var rotate = function(options, current) {
        var colon = options.indexOf(':');
        if (colon == -1) {
            return [options, current];
        }
        var next = options.substring(0, colon);
        var remaining = options.substring(colon + 1);
        if (current) remaining += ':' + current;
        return [next, remaining];
    };

    var methods = {
        init: function (options) {
            var settings = jQuery.extend({
                scroll: 'body',
                persist: true,
                restartPrompt: true,
                onSet: function (attribute, value) {}
            }, options);

            squiffy.ui.output = this;
            squiffy.ui.restart = jQuery(settings.restart);
            squiffy.ui.settings = settings;

            if (settings.scroll === 'element') {
                squiffy.ui.output.css('overflow-y', 'auto');
            }

            initLinkHandler();
            squiffy.story.begin();
            
            return this;
        },
        get: function (attribute) {
            return squiffy.get(attribute);
        },
        set: function (attribute, value) {
            squiffy.set(attribute, value);
        },
        restart: function () {
            if (!squiffy.ui.settings.restartPrompt || confirm('Are you sure you want to restart?')) {
                squiffy.story.restart();
            }
        }
    };

    jQuery.fn.squiffy = function (methodOrOptions) {
        if (methods[methodOrOptions]) {
            return methods[methodOrOptions]
                .apply(this, Array.prototype.slice.call(arguments, 1));
        }
        else if (typeof methodOrOptions === 'object' || ! methodOrOptions) {
            return methods.init.apply(this, arguments);
        } else {
            jQuery.error('Method ' +  methodOrOptions + ' does not exist');
        }
    };
})();

var get = squiffy.get;
var set = squiffy.set;


squiffy.story.start = '_default';
squiffy.story.id = '3ccbe46658';
squiffy.story.sections = {
	'_default': {
		'text': "<center><h2>A Call for Opposition to Racism</h2>\n\n<h4>Recommended Reading from the CMU English Department</h4>\n<a class=\"squiffy-link link-section\" data-section=\"start\" role=\"link\" tabindex=\"0\">start</a><br>\n&quot;It doesn&#39;t matter how strong your opinions are. If you don&#39;t use your power for positive change you are, indeed, part of the problem.&quot; \n--Coretta Scott King</center>",
		'passages': {
		},
	},
	'start': {
		'text': "<p>Are you looking for <a class=\"squiffy-link link-section\" data-section=\"fiction\" role=\"link\" tabindex=\"0\">fiction</a> or <a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">non-fiction</a>?</p>",
		'passages': {
		},
	},
	'fiction': {
		'text': "<h5><center>Fiction</center></h5>\n\n<p>Okay, what type of fiction do you need?</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Picture Books\" role=\"link\" tabindex=\"0\">Picture Books</a><br><a class=\"squiffy-link link-section\" data-section=\"Easy Readers\" role=\"link\" tabindex=\"0\">Easy Readers</a><br><a class=\"squiffy-link link-section\" data-section=\"Children\" role=\"link\" tabindex=\"0\">Children</a><br><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">Young Adult</a><br><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">Adult</a>  </p>\n<p><a class=\"squiffy-link link-section\" data-section=\"start\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
		},
	},
	'Picture Books': {
		'text': "<p><center><h5>Picture Books</h5></center>\nIt&#39;s never too early to start learning to be anti-racist!</p>\n<p><a class=\"squiffy-link link-passage\" data-passage=\"The Undefeated\" role=\"link\" tabindex=\"0\">The Undefeated</a>, by Kwame Alexander and Kadir Nelson<br><a class=\"squiffy-link link-passage\" data-passage=\"Dreamers\" role=\"link\" tabindex=\"0\">Dreamers</a>, by Yuyi Morales<br><a class=\"squiffy-link link-passage\" data-passage=\"The Other Side\" role=\"link\" tabindex=\"0\">The Other Side</a>, by Jacqueline Woodson and E.B. Lewis<br><a class=\"squiffy-link link-passage\" data-passage=\"Fry Bread\" role=\"link\" tabindex=\"0\">Fry Bread</a>, by Kevin Noble Maillard and Juana Martinez-Neal  </p>\n<p><a class=\"squiffy-link link-section\" data-section=\"fiction\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
			'The Undefeated': {
				'text': "<center><h5>The Undefeated</h5>\n<h6>by Kwame Alexander and Kadir Nelson</h6></center>\n\n<p><i>The Undefeated</i> speaks to the trauma, faith, passion, and dedication of black life in the United States.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1537505970l/40796177._SX318_.jpg\" alt=\"The Undefeated, by Kwame Alexander and Kadir Nelson\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Picture Books\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Dreamers': {
				'text': "<center><h5>Dreamers</h5>\n<h6>by Yuyi Morales</h6></center>\n\n<p>Yuyi Morales tells her story of coming to America with her infant son.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1523445744l/39651067._SX318_.jpg\" alt=\"Dreamers, by Yuyi Morales\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Picture Books\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Other Side': {
				'text': "<center><h5>The Other Side</h5>\n<h6>by Jacqueline Woodson and E.B. Lewis</h6></center>\n\n<p>A young black girl befriends a yound white girl, but the grown-ups in their lives say it isn&#39;t face to cross the fence that separate their homes.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1311279727l/129771.jpg\" alt=\"The Other Side, by Jacqueline Woodson and E.B. Lewis\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Picture Books\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Fry Bread': {
				'text': "<center><h5>Fry Bread</h5>\n<h6>by Kevin Noble Maillard and Juana Martinez-Neal</h6></center>\n\n<p>A love letter to fry bread and all the things it can represent.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1552350029l/42642044._SX318_.jpg\" alt=\"Fry Bread, by Kevin Nobel Maillard and Juana Martinez-Neil\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Picture Books\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
		},
	},
	'Easy Readers': {
		'text': "<center><h5>Easy Readers</h5></center>\n\n<p><a class=\"squiffy-link link-passage\" data-passage=\"Ling and Ting: Not Exactly the Same\" role=\"link\" tabindex=\"0\">Ling and Ting: Not Exactly the Same</a>, by Grace Lin<br><a class=\"squiffy-link link-passage\" data-passage=\"Kayla and King and the Case of the Missing Dog Treats\" role=\"link\" tabindex=\"0\">Kayla and King and the Case of the Missing Dog Treats</a>, by Dori Hillestad Butler and Nancy Meyers</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"fiction\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
			'Ling and Ting: Not Exactly the Same': {
				'text': "<center><h5>Ling and Ting: Not Exactly the Same</h5>\n<h6>by Grace Lin</h6></center>\n\n<p>Twins Ling and Ting look identical, but they are still very different.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1268703632l/7327826.jpg\" alt=\"Ling and Ting: Not Exactly the Same, by Grace Lin\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Easy Readers\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Kayla and King and the Case of the Missing Dog Treats': {
				'text': "<center><h5>King and Kayla and the Case of the Missing Dog Treats</h5>\n<h6>by Dori Hillestad Butler and Nancy Meyers</h6></center>\n\n<p>The treats Kayla made for her friend&#39;s new puppy have gone missing. Kayla and King investigate.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1480688688l/31620949._SX318_.jpg\" alt=\"Kayla and King and the Case of the Missing Dog Treats, by Dori Hellestad Butler and Nancy Meyers\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Easy Readers\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
		},
	},
	'Children': {
		'text': "<center><h5>Children&#39;s Books</h5></center>\n\n<p><a class=\"squiffy-link link-passage\" data-passage=\"When You Trap a Tiger\" role=\"link\" tabindex=\"0\">When You Trap a Tiger</a>, by Tae Keller<br><a class=\"squiffy-link link-passage\" data-passage=\"The Parker Inheritance\" role=\"link\" tabindex=\"0\">The Parker Inheritance</a>, by Varian Johnson<br><a class=\"squiffy-link link-passage\" data-passage=\"Front Desk\" role=\"link\" tabindex=\"0\">Front Desk</a>, by Kelly Yang<br><a class=\"squiffy-link link-passage\" data-passage=\"It Ain't So Awful Falafel\" role=\"link\" tabindex=\"0\">It Ain&#39;t So Awful, Falafel</a>, by Firoozeh Dumas<br><a class=\"squiffy-link link-passage\" data-passage=\"The Birchbark House\" role=\"link\" tabindex=\"0\">The Birchbark House</a>, by Louise Erdrich  </p>\n<p><a class=\"squiffy-link link-section\" data-section=\"fiction\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
			'When You Trap a Tiger': {
				'text': "<center><h5>When You Trap a Tiger</h5>\n<h6>by Tae Keller</h6></center>\n\n<p>In the summer after sixth grade, Korean-American protagonist Lily tries to trap a magical tiger in an effort to cure her dying grandmother. Drawing on Korean folktales and mythologies, rather than the stereotypes of the “magical person of color,” When you Trap a Tiger explores the experience of being Korean-American in a mostly white community and the various thoughtless (though not intentionally malicious) microaggressions that Lily and her family weather.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1561618498l/44901877.jpg\" alt=\"When You Trap a Tiger, by Tae Keller\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Children\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Parker Inheritance': {
				'text': "<center><h5>The Parker Inheritance</h5>\n<h6>by Varian Johnson</h6></center>\n\n<p>Brilliant mystery story that turns on the complexities of passing, involving twelve-year-old Candice and her efforts to understand why her grandmother—the first African American to serve as city manager—was forced to resign her position and flee town. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1496228567l/35238085._SX318_.jpg\" alt=\"The Parker Inheritance, by Varian Johnson\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Children\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Front Desk': {
				'text': "<center><h5>Front Desk</h5>\n<h6>by Kelly Yang</h6></center>\n\n<p>Chinese immigrants try to make a better life for their daughter, 10-year-old Mia, as they manage a hotel in California. The family negotiates various kinds of racism, and also tries to help the immigrant community by offering shelter in times of need at the hotel. Mia, who serves as the narrative voice and perspective, offers a wry and comedic point of view on things as she herself comes to understand the sources and structures of systemic oppression.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1507986199l/36127488.jpg\" alt=\"Front Desk, by Kelly Yang\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Children\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'It Ain\'t So Awful Falafel': {
				'text': "<center><h5>It Ain&#39;t So Awful, Falafel</h5>\n<h6>by Firoozeh Dumas</h6></center>\n\n<p>Clever, charming, informative historical realism. Book does a phenomenal job explaining the Iranian hostage crisis, along with its context within the Iranian Revolution, while also taking on a discussion of names, complexities of immigration, and politically based hostilities and prejudices directed at community members.</p>\n<p>In 1979, Iranian Zomorod Yousefzadeh lives in CA with her parents while her father (an engineer) works for an American oil company. After her father receives a more long-term position, the family moves to a new community where Zomorod, determined to make friends and fit in with her American classmates, takes up the name Cindy (after 70s sitcom character Cindy Brady, of course). After students in Iran take American embassy workers hostage, Zomorod and her family position in their community becomes more complicated.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1436842493l/25897857.jpg\" alt=\"It Ain't So Awful Falafel, by Firoozeh Dumas\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Children\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Birchbark House': {
				'text': "<center><h5>The Birchbark House series</h5>\n<h6>by Louise Erdrich</h6></center>\n\n<p>The Birchbark House, followed by The Game of Silence, The Porcupine Year, Chickadee, Makoon</p>\n<p>Multiple-award winning series about several generations of an Anishinaabe family, spanning their lives across the late 19th and early 20th centuries as their band negotiates white encroachment on their homelands in MI/WI, relocates to Dakotas, and establishes themselves there. Written as an express re-envisioning of Laura Ingalls Wilder’s much-beloved but highly problematic Little House series, Erdrich’s series carries a similar warm, family-oriented, sassy-empowered-girl feel while also offering a more complex, honest perspective on Native American/European American history and politics. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1280242695l/159666.jpg\" alt=\"The Birchbark House, by Louise Erdrich\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Children\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
		},
	},
	'Young Adult': {
		'text': "<p><a class=\"squiffy-link link-passage\" data-passage=\"Gorilla, My Love\" role=\"link\" tabindex=\"0\">Gorilla, My Love</a>, by Toni Cade Bambara\n<a class=\"squiffy-link link-passage\" data-passage=\"Pet\" role=\"link\" tabindex=\"0\">Pet</a>, by Akwaeke Emezi\n<a class=\"squiffy-link link-passage\" data-passage=\"Their Eyes Were Watching God\" role=\"link\" tabindex=\"0\">Their Eyes Were Watching God</a>, by Zora Neale Hurston\n<a class=\"squiffy-link link-passage\" data-passage=\"Annie John\" role=\"link\" tabindex=\"0\">Annie John</a>, by Jamaica Kincaid\n<a class=\"squiffy-link link-passage\" data-passage=\"Dig\" role=\"link\" tabindex=\"0\">Dig</a>, by A.S. King\n<a class=\"squiffy-link link-passage\" data-passage=\"Slay\" role=\"link\" tabindex=\"0\">Slay</a>, by Brittney Morris<br><a class=\"squiffy-link link-passage\" data-passage=\"Native Son\" role=\"link\" tabindex=\"0\">Native Son</a>, by Richard Wright</p>\n<p><a class=\"squiffy-link link-section\" data-section=\"fiction\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
			'Gorilla, My Love': {
				'text': "<center><h5>Gorilla, My Love</h5>\n<h6>by Toni Cade Bambara</h6></center>\n\n<p><i>Gorilla, My Love</i> is a collection of short stories that encompass a variety of characters and scenes, from New York to North Carlonia, from a young girl experiencing her first betrayal to a widow flirting with an elderly blind man to the chagrin of her children.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1348953076l/157927.jpg\" alt=\"Gorilla, My Love, by Toni Cade Bambara\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Pet': {
				'text': "<center><h5>Pet</h5>\n<h6>by Akwaeke Emezi</h6></center>\n\n<p>A beautiful world. Complicated plot. Set in the future, in a time after a revolution has torn down “those horrible statues of rich men who’d owned people and fought to keep owning people,” as well as banned firearms “not just because of the school shootings but also because of the kids who shot themselves and their families at home;&quot; and because of &quot;the civilians who thought they could shoot people who didn’t look like them, just because they got mad or scared or whatever, and nothing would happen to them because the old law liked them better than the dead,” the society of Lucille is peaceful, safe, loving, and free of all “monsters.” However, Lucille has also become complacent, overly confident its safety and justness, as fifteen-year-old Jam, who claimed her identity as a transgender girl at three with no more than an “all right, sweetness” from her parents, finds when a creature emerges from a painting to warn her that there is in fact a monster in Lucille. Jam must find it if to save her friend.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1550603866l/38612739.jpg\" alt=\"Pet, by Akwaeke Emezi\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Native Son': {
				'text': "<center><h5>Native Son</h5>\n<h6>by Richard Wright</h6></center>\n\n<p>In 1930s Chicago poverty and hopelessness are Bigger Thomas&#39; constant companions. In a moment of panic he kills a young white woman, and his life begins to freefall.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1440820866l/15622._SY475_.jpg\" alt=\"Native Son, by Richard Wright\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Annie John': {
				'text': "<center><h5>Annie John</h5>\n<h6>by Jamaica Kincaid</h6></center>\n\n<p>As twelve-year-old Annie grows from her mother&#39;s shadow she begins to question everything, and her relationship with her family and her home is changed forever.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1417605628l/386336.jpg\" alt=\"Annie John, by Jamaica Kincaid\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Slay': {
				'text': "<center><h5>Slay</h5>\n<h6>by Brittney Morris</h6></center>\n\n<p>17-year-old videogame developer Kiera Johnson creates a “black only” videogame to offer a safe space for black gamers, including herself. When the game gets national media, she tries to figure out how to preserve both the integrity of her game but also “what it means to unapologetically Black in a world intimidated by Blackness.”</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1551904228l/43723509.jpg\" alt=\"Slay, by Brittney Morris\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Their Eyes Were Watching God': {
				'text': "<center><h5>Their Eyes Were Watching God</h5>\n<h6>by Zora Neale Hurston</h6></center>\n\n<p>Hurston&#39;s heroine Janie Crawford sets out to be her own person, despite the obstacles that face her as a black woman in the &#39;30s.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1368072803l/37415.jpg\" alt=\"Their Eyes Were Watching God, by Zora Neale Hurston\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Dig': {
				'text': "<center><h5>Dig</h5>\n<h6>by A.S. King</h6></center>\n\n<p>Highly complicated in both narrative style and subject, Dig “not only discusses the way whiteness operates, but it interrogates the silence … around racism and white privilege.” Focused around a set of five teens, who do not realize they are related, and three generations of their family, the book looks at the legacy of white supremacy and its impact on one family, while also offering some hope that the younger generation may be able to dig themselves out.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1531335140l/40714769._SY475_.jpg\" alt=\"Dig, by A.S. King\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Young Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
		},
	},
	'Adult': {
		'text': "<p><a class=\"squiffy-link link-passage\" data-passage=\"If Beale Street Could Talk\" role=\"link\" tabindex=\"0\">If Beale Street Could Talk</a>, by James Baldwin<br><a class=\"squiffy-link link-passage\" data-passage=\"Parable of the Sower\" role=\"link\" tabindex=\"0\">Parable of the Sower</a>, by Octavia E. Butler<br><a class=\"squiffy-link link-passage\" data-passage=\"The Round House\" role=\"link\" tabindex=\"0\">The Round House</a>, by Louise Erdrich<br><a class=\"squiffy-link link-passage\" data-passage=\"Invisible Man\" role=\"link\" tabindex=\"0\">Invisible Man</a>, by Ralph Ellison<br><a class=\"squiffy-link link-passage\" data-passage=\"Juneteenth\" role=\"link\" tabindex=\"0\">Juneteenth</a>, by Ralph Ellison<br><a class=\"squiffy-link link-passage\" data-passage=\"A Raisin in the Sun\" role=\"link\" tabindex=\"0\">A Raisin in the Sun</a>, by Lorraine Hansberry<br><a class=\"squiffy-link link-passage\" data-passage=\"Beloved\" role=\"link\" tabindex=\"0\">Beloved</a>, by Toni Morrison<br><a class=\"squiffy-link link-passage\" data-passage=\"The Underground Railroad\" role=\"link\" tabindex=\"0\">The Underground Railroad</a>, by Colson Whitehead<br><a class=\"squiffy-link link-passage\" data-passage=\"Fences\" role=\"link\" tabindex=\"0\">Fences</a>, by August Wilson  </p>\n<p><a class=\"squiffy-link link-section\" data-section=\"fiction\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
			'If Beale Street Could Talk': {
				'text': "<center><h5>If Beale Street Could Talk</h5>\n<h6>by James Baldwin</h6></center>\n\n<p>Nineteen-year-old Tish is pledged to marry the father of her child, but he is falsely accused of a terrible crime and imprisioned. As their families work toward Fonny&#39;s freedom the two experience a full spectrum of emotion, from despair to hope.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1388182698l/38463.jpg\" alt=\"If Beale Street Could Talk, by James Baldwin\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Parable of the Sower': {
				'text': "<center><h5>Parable of the Sower</h5>\n<h6>by Octavia E. Butler</h6></center>\n\n<p>In the first novel of Octavia E. Butler&#39;s <i>Earthseed</i> series, Lauren Olamina&#39;s life is upturned when a fire destroys her home, one of the only safe places remaining in 2025 Los Angeles, and her family is killed. Hyperempathetic Lauren and the few other refugees go north in search of safety and along the way conceive of an idea that could save everyone.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1442169447l/52397._SY475_.jpg\" alt=\"Parable of the Sower, by Octavia E. Butler\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Round House': {
				'text': "<center><h5>The Round House</h5>\n<h6>by Louise Erdrich</h6></center>\n\n<p>Set in the late 80s on an Ojibwe (Anishinaabe) reservation in North Dakota, the book looks at the complications of the legal system related to crimes against Native Americans and how they are dealt with in Native American versus State jurisdictions. Told from the perspective of the son of a woman who is raped, the story evolves as part coming of age story, part mystery, part social commentary. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1352999408l/13602426.jpg\" alt=\"The Round House, by Louise Erdrich\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Invisible Man': {
				'text': "<center><h5>Invisible Man</h5></center>\n<h6>by Ralph Ellison</h6></center>\n\n<p>Upon its publication in 1952 <i>Invisible Man</i> changed American literature forever. Its nameless protagonist travels the country, and through his eyes we see the effects of bigotry on both victims and perpetrators.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1556482805l/16981._SY475_.jpg\" alt=\"Invisible Man, Ralph Ellison\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Juneteenth': {
				'text': "<center><h5>Juneteenth</h5>\n<h6>by Ralph Ellison</h6></center>\n\n<p>Juneteenth follows a fraught father-son relationship through the first half of the 20th century in the segregated American South, up and down the Mississippi river and the East Coast over the course of 50 years. Ellison sought to characterize both American and African-American culture, music, religion, politics, values, and desires. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1388982209l/15151.jpg\" alt=\"Juneteenth, by Ralph Ellison\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'A Raisin in the Sun': {
				'text': "<center><h5>A Rasin in the Sun</h5>\n<h6>Lorraine Hansberry</h6></center>\n\n<p>In 1959 Hansberry became the first African American woman ever to have a play open on Broadway . Set in Chicago, the play is about segregation and integration in the north,  immediately before the Civil Rights Act of 1964. The issue of “redlining” still exists today, though it is technically illegal.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1165522672l/5517.jpg\" alt=\"A Raisin in the Sun, by Lorraine Hansberry\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Beloved': {
				'text': "<p><center><h5>Beloved</h5></p>\n<h6>by Toni Morrison</h6>\n\n<p>Toni Morrison&#39;s haunting Pulitzer Prize winner <i>Beloved</i> follows former slave Sethe eighteen years after her escape to Ohio as she is tormented by the ghost of her nameless baby. As Sethe struggles to escape her own memories a mysterious but familiar young woman appears into her life.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1347984578l/6149.jpg\" alt=\"Beloved, by Toni Morrison\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Underground Railroad': {
				'text': "<center><h5>The Underground Railroad</h5>\n<h6>by Colson Whitehead</h6></center>\n\n<p>Imagining the underground railroad as a real train network, Whitehead’s story of a young woman’s experience of and escape from slavery offer a provocative meditation on both American history and the present day. Winner of the 2016 Pulitzer Prize AND the National Book Award. Truly a fantastic book.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1493178362l/30555488.jpg\" alt=\"The Underground Railroad, by Colson Whitehead\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Fences': {
				'text': "<center><h5>Fences</h5>\n<h6>by August Wilson</h6></center>\n\n<p>The Pittsburgh Cycle is Wilson’s ambitious project to write a play about the African American experience in every decade of the twentieth century. Many significant, award winning plays came out of this project, including Fences (1987), set in the 1940s and later turned into a film starring Denzel Washington and Viola Davis.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1303532209l/11188410.jpg\" alt=\"Fences, by August Wilson\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"Adult\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
		},
	},
	'non-fiction': {
		'text': "<p><a class=\"squiffy-link link-passage\" data-passage=\"The New Jim Crow: Mass Incarceration in the Age of Colorblindness\" role=\"link\" tabindex=\"0\">The New Jim Crow: Mass Incarceration in the Age of Colorblindness</a>, by Michelle Alexander<br><a class=\"squiffy-link link-passage\" data-passage=\"Our Time is Now: Power, Purpose, and the Fight for a Fair America\" role=\"link\" tabindex=\"0\">Our Time is Now: Power, Purpose, and the Fight for a Fair America</a>, by Stacey Abrams<br><a class=\"squiffy-link link-passage\" data-passage=\"I Know Why the Caged Bird Sings\" role=\"link\" tabindex=\"0\">I Know Why the Caged Bird Sings</a>, by Maya Angelou<br><a class=\"squiffy-link link-passage\" data-passage=\"The Fire Next Time\" role=\"link\" tabindex=\"0\">The Fire Next Time</a>, by James Baldwin<br><a class=\"squiffy-link link-passage\" data-passage=\"Between the World and Me\" role=\"link\" tabindex=\"0\">Between the World and Me</a>, by Ta-Nehisi Coates<br><a class=\"squiffy-link link-passage\" data-passage=\"Stony the Road: Reconstruction, White Supremacy, and the Rise of Jim Crow\" role=\"link\" tabindex=\"0\">Stony the Road: Reconstruction, White Supremacy, and the Rise of Jim Crow</a>, by Henry Louis Gates, Jr.<br><a class=\"squiffy-link link-passage\" data-passage=\"Killers of the Flower Moon: The Osage Murders and the Birth of the FBI\" role=\"link\" tabindex=\"0\">Killers of the Flower Moon: The Osage Murders and the Birth of the FBI</a>, by David Grann<br><a class=\"squiffy-link link-passage\" data-passage=\"Five Days: The Fiery Reckoning of an American City\" role=\"link\" tabindex=\"0\">Five Days: The Fiery Reckoning of an American City</a>, by Wes Moore<br><a class=\"squiffy-link link-passage\" data-passage=\"Pushout: The Criminalization of Black Girls in Schools\" role=\"link\" tabindex=\"0\">Pushout: The Criminalization of Black Girls in Schools</a>  , by Monique W. Morris<br><a class=\"squiffy-link link-passage\" data-passage=\"Sojourner Truth: A Life, A Symbol\" role=\"link\" tabindex=\"0\">Sojourner Truth: A Life, A Symbol</a>, by Nell Irvin Painter<br><a class=\"squiffy-link link-passage\" data-passage=\"The Warmth of Other Suns: The Epic Story of America's Great Migration\" role=\"link\" tabindex=\"0\">The Warmth of Other Suns: The Epic Story of America&#39;s Great Migration</a>, by Isabel Wilkerson<br><a class=\"squiffy-link link-passage\" data-passage=\"The Autobiography of Malcolm X\" role=\"link\" tabindex=\"0\">The Autobiography of Malcolm X</a>, by Malcolm X, as told to Alex Haley  </p>\n<p><a class=\"squiffy-link link-section\" data-section=\"start\" role=\"link\" tabindex=\"0\">looking for something else?</a></p>",
		'passages': {
			'The New Jim Crow: Mass Incarceration in the Age of Colorblindness': {
				'text': "<center><h5>The New Jim Crow: Mass Incarceration in the Age of Colorblindness</h5>\n<h6>by Michelle Alexander</h6></center>\n\n<p>For the tenth anniversary of The New Jim Crow, Alexander published the following editorial in the New York Times, months before the murder of George Floyd. “The Injustice of This Moment Is Not an ‘Aberration’: From mass incarceration to mass deportation, our nation remains in deep denial.”</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1328751532l/6792458.jpg\" alt=\"The New Jim Crow: Mass Incarceration in the Age of Colorblindness, by Michelle Alexander\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Our Time is Now: Power, Purpose, and the Fight for a Fair America': {
				'text': "<center><h5>Our Time is Now: Power, Purpose, and the Fight for a Fair America</h5>\n<h6>by Stacey Abrams</h6></center>\n\n<p>Abrams came close to winning the governorship of Georgia in 2018—1.9 million Democratic votes were cast in the election, the most in Georgia history. She would have been the first African America woman to hold that office anywhere in the United States. There is strong evidence that she lost due to voter suppression. Despite ongoing voter suppression, Abrams believes that the way forward in fighting against systemic racism (and any other fight, such as climate change) is through voting. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1578507676l/50353732._SY475_.jpg\" alt=\"Our Time is Now: Power, Purpose, and the Fight for a Fair America, by Stacey Abrams\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'I Know Why the Caged Bird Sings': {
				'text': "<center><h5>I Know Why the Caged Bird Sings</h5>\n<h6>by Maya Angelou</h6></center>\n\n<p>A memoir of growing up in the segregated world of the Jim Crow in the 1930s and 1940s, Angelou documents a chaotic and traumatic childhood in rural Arkansas, St. Louis, and San Francisco. She went on to be a successful author. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1327957927l/13214.jpg\" alt=\"I Know Why the Caged Bird Sings, by Maya Angelou\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Fire Next Time': {
				'text': "<center><h5>The Fire Next Time</h5>\n<h6>by James Baldwin</h6></center>\n\n<p>Part memoir, part letter to Americans on the centennial of the Emancipation Proclamation, James Baldwin&#39;s bestselling The Fire Next Time encourages all Americans to tear down the legacy of racism.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1562890148l/464260._SY475_.jpg\" alt=\"The Fire Next Time, by James Baldwin\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Between the World and Me': {
				'text': "<p><center><h5>Between the World and Me</h5></p>\n<h6>by Ta-Nehisi Coates</h6>\n\n<p>Framed as a letter to his son, Ta-Nehisi Coates explores the historical and current exploitation of black Americans, the experience of life in a black body, and how we might free ourselves from a history of racism.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1451435027l/25489625._SY475_.jpg\" alt=\"Between the World and Me, by Ta-Nehisi Coates\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Stony the Road: Reconstruction, White Supremacy, and the Rise of Jim Crow': {
				'text': "<center><h5>Stony the Road: Reconstruction, White Supremacy, and the Rise of Jim Crow</h5>\n<h6>by Henry Louis Gates, Jr.</h6></center>\n\n<p>This book lays out the history of systemic racism in the United States.\n“How does white supremacy work? What does it look like? In this piercing, haunting study, Henry Louis Gates, Jr., chronicles an American tragedy, the story of how white supremacy and Jim Crow became the South’s—and white America’s—brutal answer to Emancipation and Reconstruction. Who has best dismantled white supremacy, and how? Gates tells those powerful stories, too, from Frederick Douglass to Ida B. Wells to W. E. B. DuBois, through generations of New Negroes, and New, New Negroes, battling back, in struggles not yet ended.” —Jill Lepore, author of These Truths: A History of the United States\nGates is a professor at Harvard and the host of “Finding Your Roots” on PBS\nThe title is an allusion to the song, “Lift Every Voice and Sing,” often referred to as the Black national anthem. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1534284832l/40909438.jpg\" alt=\"Stony the Road: Reconstruction, White Supremacy, and the Rise of Jim Crow, by Henry Louis Gates, Jr.\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Killers of the Flower Moon: The Osage Murders and the Birth of the FBI': {
				'text': "<center><h5>Killers of the Flower Moon: The Osage Murders and the Birth of the FBI</h5>\n<h6>by David Grann</h6></center>\n\n<p>At about the same time as the massacre on Black Wall Street in Greenwood OK outside Tulsa in 1921, white people (mostly men) were marrying into the nearby Osage tribe in Osage Co. OK, and then murdering their spouses to inherit the land and, more importantly, the mineral and oil rights.  Over a several year period, at least 20 murders are known to have been committed, but more are suspected, perhaps hundreds.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1470699853l/29496076.jpg\" alt=\"Killers of the Flower Moon: The Osage Murders and the Birth of the FBI\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Five Days: The Fiery Reckoning of an American City': {
				'text': "<center><h5>Five Days: The Fiery Reckoning of an American City</h5>\n<h6>by Wes Moore</h6></center>\n\n<p>Moore’s latest book, Five Days: The Fiery Reckoning of an American City (2020), about what happened in Baltimore following the death of Freddie Gray while in police custody in 2015, was just published in June, the same period of time as George Floyd was murdered in police custody (May 25, 2020). </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1576625937l/52913077._SX318_SY475_.jpg\" alt=\"Five Days: The Fiery Reckoning of an American City, by Wes Moore\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Pushout: The Criminalization of Black Girls in Schools': {
				'text': "<center><h5>Pushout: The Criminalization of Black Girls in Schools</h5>\n<h6>by Monique W. Morris</h6></center>\n\n<p>Monique W. Morris shares the experiences of black girls across America and the institutions that gravely misunderstand them.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1455172864l/25159334.jpg\" alt=\"Pushout: The Criminalization of Black Girls in Schools, by Monique W. Morris\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'Sojourner Truth: A Life, A Symbol': {
				'text': "<center><h5>Sojourner Truth: A Life, A Symbol</h5>\n<h6>by Nell Irvin Painter</h6></center>\n\n<p>Born into slavery, Sojourner Truth made herself into a symbol of strength and respect, not only for black women, but for all women.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1389219213l/256976.jpg\" alt=\"Sojourner Truth: A Life, A Symbol, by Nell Irvin Painter\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Warmth of Other Suns: The Epic Story of America\'s Great Migration': {
				'text': "<center><h5>The Warmth of Other Suns: The Epic Story of America&#39;s Great Migration </h5>\n<h6>Isabel Wilkerson</h6></center>\n\n<p>Pulitzer Prizewinner Isabel Wilkerson tells the stories of three black citizens who fled the South in search of a better life and how they changed the cities that became their new homes. </p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1433354252l/8171378._SY475_.jpg\" alt=\"The Warmth of Other Suns: The Epic Story of America's Great Migration, by Isabel Wilkerson\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
			'The Autobiography of Malcolm X ': {
				'text': "<center><h5>The Autobiography of Malcolm X</h5>\n<h6>by Malcolm X, as told to Alex Haley</h6></center>\n\n<p>The legendary self-described &quot;angriest Black man in America&quot; tells his own story to <i>Roots: The Saga of an American Family</i> author Alex Haley.</p>\n<p><img src=\"https://i.gr-assets.com/images/S/compressed.photo.goodreads.com/books/1434682864l/92057.jpg\" alt=\"The Autobiography of Malcolm X, by Malcolm X, as told to Alex Haley\" style=\"width:100%; height:auto\" align=\"right\"></p>\n<p><a class=\"squiffy-link link-section\" data-section=\"non-fiction\" role=\"link\" tabindex=\"0\">choose another?</a></p>\n<hr>",
			},
		},
	},
}
})();